@@ -130,10 +130,10 @@ class ParseMCNPCell:
                 except MissingLatticeOptError as err:
                     msg = '{} for cell {}'.format(err, key)
                     raise MissingLatticeOptError(msg) from None
-                except tatsu.exceptions.ParseException:
+                except tatsu.exceptions.ParseException as err:
                     msg = ('TatSu parsing failed for cell {}. Check the '
                            'syntax of this cell.'.format(key))
-                    raise ParseMCNPCellError(msg)
+                    raise ParseMCNPCellError(msg) from err
                 if cell.importance == 0:
                     skipped_cells.append(key)
                 dict_cell[key] = cell
@@ -188,7 +188,7 @@ class ParseMCNPCell:
         if int(material_id) == 0:
             density = None
         else:
-            density = normalize_density(material.split()[1])
+            density = material.split()[1]
         return material_id, density
 
     @staticmethod
@@ -245,14 +245,14 @@ class ParseMCNPCell:
                 keywords['u'] = int(float(kw_list.pop()))
             elif 'rho' in elt:
                 # only relevant for LIKE n BUT cells
-                keywords['density'] = normalize_density(kw_list.pop())
+                keywords['density'] = kw_list.pop()
             elif 'mat' in elt:
                 # only relevant for LIKE n BUT cells
                 keywords['material'] = kw_list.pop()
         return keywords
 
     def parse_fill_kw(self, elt, kw_list):
-        '''Parse the arguments of the FILL and \*FILL keywords.'''
+        '''Parse the arguments of the FILL and *FILL keywords.'''
         fillid_bounds = None
         fillid_u = None
         fill_params = []
@@ -309,7 +309,7 @@ class ParseMCNPCell:
         return lattice
 
     def parse_trcl_kw(self, elt, kw_list):
-        '''Parse the arguments of the TRCL and \*TRCL keywords.'''
+        '''Parse the arguments of the TRCL and *TRCL keywords.'''
         trcl_params = []
         while kw_list and kw_list[-1][0] in '0123456789.+-':
             trcl_params.append(kw_list.pop())
@@ -328,28 +328,3 @@ class ParseMCNPCell:
         elif '*' in elt:
             trcl_params[3:] = list(map(to_cos, trcl_params[3:12]))
         return tuple(trcl_params)
-
-
-def normalize_density(density):
-    '''Return a normalized version of the density, removing any trailing
-    zeros, except one if it is the only digit after the decimal point.
-
-    Examples:
-
-    >>> normalize_density('1.0')
-    '1.0'
-    >>> normalize_density('1.23000')
-    '1.23'
-    >>> normalize_density('-1.23000')
-    '-1.23'
-    >>> normalize_density('-.23000')
-    '-.23'
-    >>> normalize_density('7')
-    '7'
-    >>> normalize_density('10')
-    '10'
-    '''
-    norm = re.sub(r'^([-+]?[0-9]*\.[0-9]*[^0])0+$', r'\1', density)
-    if norm[-1] == '.':
-        norm += '0'
-    return norm
